pub enum ConditionalKind {
If,
While,
}Expand description
Kind of conditional node. Matches CU_GRAPH_COND_TYPE_*.
Variants
If
Execute the inner graph at most once when the handle’s value is non-zero.
While
Execute the inner graph repeatedly while the handle’s value stays non-zero. The inner graph is responsible for clearing the handle when it should exit.